@@ -48,7 +48,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.64_04'; # TRIAL VERSION
+our $VERSION = '1.65_01'; # TRIAL VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -71,10 +71,10 @@ our $VERSION = '1.64_04'; # TRIAL VERSION
     Bourso
     BVB
     CSE
+    CMBChina
     Comdirect
     Consorsbank
     Currencies
-    DWS
     Deka
     FinanceAPI
     Finanzpartner
@@ -83,7 +83,6 @@ our $VERSION = '1.64_04'; # TRIAL VERSION
     FTfunds
     GoldMoney
     GoogleWeb
-    HU
     IndiaMutual
     MarketWatch
     MorningstarCH
@@ -92,8 +91,6 @@ our $VERSION = '1.64_04'; # TRIAL VERSION
     NSEIndia
     NZX
     OnVista
-    Oslobors
-    SEB
     SIX
     Sinvestor
     StockData
@@ -606,14 +603,20 @@ sub fetch {
     return;
   }
 
-  # Temporary Counting - not concerned about return code
-  # my $COUNT_URL =
-  #   'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $method;
-  # my $count_ua = LWP::UserAgent->new(timeout => 10);
-  # my $count_response = $count_ua->head($COUNT_URL);
+  {
+    no strict 'vars';
+    our $VERSION = '0.00' unless defined $VERSION;
+    unless ($ENV{"FQ_NOCOUNT"}) {
+      # Temporary Counting - not concerned about return code
+      my $COUNT_URL =
+        'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $VERSION . '&' . $method;
+      my $count_ua = LWP::UserAgent->new(timeout => 10);
+      my $count_response = $count_ua->head($COUNT_URL);
 
-  # ### COUNT_URL: $COUNT_URL
-  # ### Code: $count_response->code
+      ### COUNT_URL: $COUNT_URL
+      ### Code: $count_response->code
+    }
+  }
 
   # Failover code.  This steps through all available methods while
   # we still have failed stocks to look-up.  This loop only
@@ -1619,6 +1622,10 @@ Finance::Quote respects all environment that your installed version of
 LWP::UserAgent respects.  Most importantly, it respects the http_proxy
 environment variable.
 
+=head1 USAGE COUNTER
+
+A simple usage counter has been enabled. Other than the user's IP address, Finance::Quote version, and which method was used, no other data is collected. To opt out of your usage being counted, set the environment variable "FQ_NOCOUNT".
+
 =head1 BUGS
 
 The caller cannot control the fetch failover order.
@@ -1708,8 +1715,8 @@ http://www.gnucash.org/
   Finance::Quote::CSE,
   Finance::Quote::Comdirect,
   Finance::Quote::Consorsbank,
+  Finance::Quote::CMBChina,
   Finance::Quote::Currencies,
-  Finance::Quote::DWS,
   Finance::Quote::Deka,
   Finance::Quote::FinanceAPI,
   Finance::Quote::Finanzpartner,
@@ -1718,7 +1725,6 @@ http://www.gnucash.org/
   Finance::Quote::FTfunds,
   Finance::Quote::GoldMoney,
   Finance::Quote::GoogleWeb,
-  Finance::Quote::HU,
   Finance::Quote::IndiaMutual,
   Finance::Quote::MarketWatch,
   Finance::Quote::MorningstarCH,
@@ -1727,8 +1733,6 @@ http://www.gnucash.org/
   Finance::Quote::NSEIndia,
   Finance::Quote::NZX,
   Finance::Quote::OnVista,
-  Finance::Quote::Oslobors,
-  Finance::Quote::SEB,
   Finance::Quote::SIX,
   Finance::Quote::StockData,
   Finance::Quote::Stooq,
@@ -1749,7 +1753,7 @@ Please read it if you are interested in adding extra methods to this package.
 The latest hacker's guide can also be found on GitHub at
 https://github.com/finance-quote/finance-quote/blob/master/Documentation/Hackers-Guide
 
-=head1 Donations
+=head1 DONATIONS
 
 While the contributors to Finance::Quote are happy to volunteer their time and resources on this project, donations are helpful and great way to say thank you. So far the only real cost to the team is domain registration for finance-quote.org. However, some operating systems and hardware upgrades do have a cost. Access to the latest or current environments is needed for development and testing. Upgrades to the latest MS Windows often includes a cost, and recently Apple's move to ARM/M1/M2 CPUs has stifled some contributors' ability to assist. With that in mind, you can send donations to the email address donations@finance-quote.org through PayPal. If it's for a particular contributor, please indicate in a note while submitting the donation through PayPal.
 
