@@ -25,7 +25,7 @@ package Finance::Quote::OnVista;
 use strict;
 use warnings;
 
-use Encode qw(decode encode_utf8);
+use Encode qw(encode_utf8);
 use HTML::TreeBuilder;
 use HTTP::Request::Common;
 use JSON qw( decode_json );
@@ -35,7 +35,7 @@ use POSIX qw(strftime);
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.64_04'; # TRIAL VERSION
+our $VERSION = '1.65_01'; # TRIAL VERSION
 
 my $ONVISTA_URL = 'https://www.onvista.de/suche/';
 
@@ -43,10 +43,12 @@ my $ONVISTA_URL = 'https://www.onvista.de/suche/';
 # Modify LABELS to those returned by the method
 
 our $DISPLAY    = 'OnVista - Germany';
-our @LABELS     = qw/symbol isin wkn name open close high low last date volume currency exchange method ask bid p_change time/;
-our $METHODHASH = {subroutine => \&onvista, 
-                   display => $DISPLAY, 
-                   labels => \@LABELS};
+our $FEATURES   = { 'EXCHANGE' => 'select market place (i.e. "GER", "Xetra", "Tradegate")' };
+our @LABELS     = qw/symbol isin wkn name open close high low last date volume currency exchange method ask bid change p_change time exchanges source/;
+our $METHODHASH = {subroutine => \&onvista,
+                   display => $DISPLAY,
+                   labels => \@LABELS,
+                   features => $FEATURES};
 
 sub methodinfo {
     return ( 
@@ -151,7 +153,7 @@ sub onvista {
         }
         $tree->eof;
 
-        unless ( $json = encode_utf8 (($tree->look_down(_tag => 'script', id => '__NEXT_DATA__', type => 'application/json')->content_list())[0]) ) {
+        unless ( $json = encode_utf8(($tree->look_down(_tag => 'script', id => '__NEXT_DATA__', type => 'application/json')->content_list())[0]) ) {
           $info{ $stock, "success" } = 0;
           $info{ $stock, "errormsg" } =
             "Error retrieving quote for $stock. No data returned";
@@ -160,24 +162,47 @@ sub onvista {
 
         ### [<now>] 2nd JSON: $json
 
-        eval {$json_decoded = decode_json $json};
+        eval {$json_decoded = decode_json encode_utf8 $json};
         if($@) {
           $info{ $stock, 'success' } = 0;
           $info{ $stock, 'errormsg' } = $@;
           next;
         }
 
+        my $exchange = exists $quoter->{module_specific_data}->{onvista}->{EXCHANGE} ?
+                              $quoter->{module_specific_data}->{onvista}->{EXCHANGE} : undef;
+
+        my $markets = $json_decoded->{'props'}{'pageProps'}{'data'}{'snapshot'}{'quoteList'}{'list'};
+        $info{ $stock, 'exchanges' } = [ map { $_->{'market'}{'name'} } @$markets ];
+
+        my $json_quote;
+        if ($exchange) {
+          ($json_quote) = grep { $_->{'market'}{'name'} eq $exchange
+                              or $_->{'market'}{'codeExchange'} eq $exchange
+                               } @$markets;
+          unless($json_quote) {
+            $info{ $stock, "success" } = 0;
+            $info{ $stock, "errormsg" } =
+                "Error retrieving quote for $stock. No data returned for $exchange";
+            next;
+          }
+        } else {
+          $json_quote = $json_decoded->{'props'}{'pageProps'}{'data'}{'snapshot'}{'quote'};
+        }
+
         ### [<now>] 2nd JSON Decoded: $json_decoded
 
         $info{ $stock, "success" } = 1;
         $info{ $stock, 'method' } = 'onvista';
+        $info{ $stock, 'source' } = $url;
         $info{ $stock, 'name' } = $json_decoded->{'props'}{'pageProps'}{'data'}{'snapshot'}{'instrument'}{'name'};
-        my $json_quote = $json_decoded->{'props'}{'pageProps'}{'data'}{'snapshot'}{'quote'};
+
         map { $info{ $stock, $_ } = $json_quote->{$_} } qw(open high low last volume ask bid);
         $info{ $stock, 'price' } = $json_quote->{'last'};
         $info{ $stock, 'currency' } = $json_quote->{'isoCurrency'};
         $info{ $stock, 'exchange' } = $json_quote->{'market'}{'name'};
         $info{ $stock, 'close' } = $json_quote->{'previousLast'};
+        $info{ $stock, 'change' } = $json_quote->{'performance'};
         $info{ $stock, 'p_change' } = $json_quote->{'performancePct'};
         $quoter->store_date(\%info, $stock, {isodate => substr $json_quote->{'datetimeLast'}, 0, 10});
 
@@ -217,9 +242,13 @@ Finance::Quote::OnVista - Obtain quotes from Frankfurt Stock Exchange.
     use Finance::Quote;
 
     $q = Finance::Quote->new;
+    or
+    $q = Finance::Quote->new("OnVista", "onvista" => { "EXCHANGE" => "Xetra" });
 
     %info = $q->fetch("onvista", "sap");  # Only query onvista
 
+    @exchanges = @{ $info{ "sap", "exchanges" } }; # List of available marketplaces
+
 =head1 DESCRIPTION
 
 This module fetches information from L<https://onvista.de/>.
@@ -234,6 +263,19 @@ to replace a non-working Tradeville.pm module.
 Information obtained by this module may be covered by Frankfurt Stock
 Exchange terms and conditions.
 
+=head1 EXCHANGE
+
+https://onvista.de/ supports different market places. A default is not specified.
+
+  "Xetra" alias "GER"
+  "Tradegate" alias "GAT"
+  "gettex" alias "TRO"
+  "London Stock Exchange" alias "LSE"
+  ... any many more ...
+
+The EXCHANGE may be set by providing a module specific hash to
+Finance::Quote->new as in the above example (optional).
+
 =head1 LABELS RETURNED
 
 The following labels are returned: 
@@ -268,6 +310,10 @@ The following labels are returned:
 
 =item currency
 
+=item change
+
 =item p_change
 
+=item source
+
 =back
