@@ -36,7 +36,7 @@ use URI::Escape;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments';
 
-our $VERSION = '1.64_04'; # TRIAL VERSION
+our $VERSION = '1.65_01'; # TRIAL VERSION
 
 # Required to successfully read extra long headers returned from yahoo
 my %OPTS = @LWP::Protocol::http::EXTRA_SOCK_OPTS;
@@ -228,7 +228,7 @@ sub yahoo_json {
                   # in Strawberry perl 5.18.2 in Windows
                   local $^W = 0;
                   $info{ $stocks, "div_yield" } =
-                    $json_resources_summaryDetail->{'trailingAnnualDividendYield'}{'raw'} =~ m/[\d,\.]+/ ?
+                    $json_resources_summaryDetail->{'trailingAnnualDividendYield'}{'raw'} =~ m/^[\d,\.]+$/ ?
                     $json_resources_summaryDetail->{'trailingAnnualDividendYield'}{'raw'} * 100          :
                     0.0;
                 }
